@@ -210,7 +210,7 @@ class WorkSpacesWebClient(BaseClient):
     def create_trust_store(
         self,
         *,
-        certificateList: Sequence[Union[bytes, IO[bytes], StreamingBody]],
+        certificateList: Sequence[Union[str, bytes, IO[Any], StreamingBody]],
         clientToken: str = ...,
         tags: Sequence["TagTypeDef"] = ...
     ) -> CreateTrustStoreResponseTypeDef:
@@ -555,7 +555,7 @@ class WorkSpacesWebClient(BaseClient):
         self,
         *,
         trustStoreArn: str,
-        certificatesToAdd: Sequence[Union[bytes, IO[bytes], StreamingBody]] = ...,
+        certificatesToAdd: Sequence[Union[str, bytes, IO[Any], StreamingBody]] = ...,
         certificatesToDelete: Sequence[str] = ...,
         clientToken: str = ...
     ) -> UpdateTrustStoreResponseTypeDef:
