@@ -13,10 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Dict, List, Mapping, Sequence, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import EnabledTypeType, IdentityProviderTypeType, PortalStatusType
 
@@ -369,7 +368,7 @@ CreatePortalResponseTypeDef = TypedDict(
 _RequiredCreateTrustStoreRequestRequestTypeDef = TypedDict(
     "_RequiredCreateTrustStoreRequestRequestTypeDef",
     {
-        "certificateList": Sequence[Union[bytes, IO[bytes], StreamingBody]],
+        "certificateList": Sequence[Union[str, bytes, IO[Any], StreamingBody]],
     },
 )
 _OptionalCreateTrustStoreRequestRequestTypeDef = TypedDict(
@@ -1094,7 +1093,7 @@ _RequiredUpdateTrustStoreRequestRequestTypeDef = TypedDict(
 _OptionalUpdateTrustStoreRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateTrustStoreRequestRequestTypeDef",
     {
-        "certificatesToAdd": Sequence[Union[bytes, IO[bytes], StreamingBody]],
+        "certificatesToAdd": Sequence[Union[str, bytes, IO[Any], StreamingBody]],
         "certificatesToDelete": Sequence[str],
         "clientToken": str,
     },
